# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DomainLogicalInterface(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainLogicalInterface - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'edge_uri': 'str',
            'edge_assigned_id': 'str',
            'friendly_name': 'str',
            'vlan_tag_id': 'int',
            'hardware_address': 'str',
            'physical_adapter_id': 'str',
            'ip_address': 'str',
            'gateway': 'str',
            'primary_dns': 'str',
            'secondary_dns': 'str',
            'if_status': 'str',
            'routes': 'list[DomainNetworkRoute]',
            'addresses': 'list[DomainNetworkAddress]',
            'ipv4_capabilities': 'DomainCapabilities',
            'ipv6_capabilities': 'DomainCapabilities',
            'current_state': 'str',
            'last_modified_user_id': 'str',
            'last_modified_correlation_id': 'str',
            'command_responses': 'list[DomainNetworkCommandResponse]',
            'inherit_phone_trunk_bases': 'bool',
            'inherit_phone_trunk_bases_i_pv4': 'bool',
            'inherit_phone_trunk_bases_i_pv6': 'bool',
            'use_for_internal_edge_communication': 'bool',
            'external_trunk_base_assignments': 'list[TrunkBaseAssignment]',
            'phone_trunk_base_assignments': 'list[TrunkBaseAssignment]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'edge_uri': 'edgeUri',
            'edge_assigned_id': 'edgeAssignedId',
            'friendly_name': 'friendlyName',
            'vlan_tag_id': 'vlanTagId',
            'hardware_address': 'hardwareAddress',
            'physical_adapter_id': 'physicalAdapterId',
            'ip_address': 'ipAddress',
            'gateway': 'gateway',
            'primary_dns': 'primaryDns',
            'secondary_dns': 'secondaryDns',
            'if_status': 'ifStatus',
            'routes': 'routes',
            'addresses': 'addresses',
            'ipv4_capabilities': 'ipv4Capabilities',
            'ipv6_capabilities': 'ipv6Capabilities',
            'current_state': 'currentState',
            'last_modified_user_id': 'lastModifiedUserId',
            'last_modified_correlation_id': 'lastModifiedCorrelationId',
            'command_responses': 'commandResponses',
            'inherit_phone_trunk_bases': 'inheritPhoneTrunkBases',
            'inherit_phone_trunk_bases_i_pv4': 'inheritPhoneTrunkBasesIPv4',
            'inherit_phone_trunk_bases_i_pv6': 'inheritPhoneTrunkBasesIPv6',
            'use_for_internal_edge_communication': 'useForInternalEdgeCommunication',
            'external_trunk_base_assignments': 'externalTrunkBaseAssignments',
            'phone_trunk_base_assignments': 'phoneTrunkBaseAssignments',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._edge_uri = None
        self._edge_assigned_id = None
        self._friendly_name = None
        self._vlan_tag_id = None
        self._hardware_address = None
        self._physical_adapter_id = None
        self._ip_address = None
        self._gateway = None
        self._primary_dns = None
        self._secondary_dns = None
        self._if_status = None
        self._routes = None
        self._addresses = None
        self._ipv4_capabilities = None
        self._ipv6_capabilities = None
        self._current_state = None
        self._last_modified_user_id = None
        self._last_modified_correlation_id = None
        self._command_responses = None
        self._inherit_phone_trunk_bases = False
        self._inherit_phone_trunk_bases_i_pv4 = False
        self._inherit_phone_trunk_bases_i_pv6 = False
        self._use_for_internal_edge_communication = False
        self._external_trunk_base_assignments = None
        self._phone_trunk_base_assignments = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DomainLogicalInterface.
        The globally unique identifier for the object.

        :return: The id of this DomainLogicalInterface.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DomainLogicalInterface.
        The globally unique identifier for the object.

        :param id: The id of this DomainLogicalInterface.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DomainLogicalInterface.


        :return: The name of this DomainLogicalInterface.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DomainLogicalInterface.


        :param name: The name of this DomainLogicalInterface.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DomainLogicalInterface.


        :return: The description of this DomainLogicalInterface.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DomainLogicalInterface.


        :param description: The description of this DomainLogicalInterface.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this DomainLogicalInterface.


        :return: The version of this DomainLogicalInterface.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DomainLogicalInterface.


        :param version: The version of this DomainLogicalInterface.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this DomainLogicalInterface.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this DomainLogicalInterface.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DomainLogicalInterface.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this DomainLogicalInterface.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DomainLogicalInterface.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this DomainLogicalInterface.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DomainLogicalInterface.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this DomainLogicalInterface.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this DomainLogicalInterface.


        :return: The modified_by of this DomainLogicalInterface.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this DomainLogicalInterface.


        :param modified_by: The modified_by of this DomainLogicalInterface.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this DomainLogicalInterface.


        :return: The created_by of this DomainLogicalInterface.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this DomainLogicalInterface.


        :param created_by: The created_by of this DomainLogicalInterface.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this DomainLogicalInterface.


        :return: The state of this DomainLogicalInterface.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this DomainLogicalInterface.


        :param state: The state of this DomainLogicalInterface.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this DomainLogicalInterface.


        :return: The modified_by_app of this DomainLogicalInterface.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this DomainLogicalInterface.


        :param modified_by_app: The modified_by_app of this DomainLogicalInterface.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this DomainLogicalInterface.


        :return: The created_by_app of this DomainLogicalInterface.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this DomainLogicalInterface.


        :param created_by_app: The created_by_app of this DomainLogicalInterface.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def edge_uri(self):
        """
        Gets the edge_uri of this DomainLogicalInterface.


        :return: The edge_uri of this DomainLogicalInterface.
        :rtype: str
        """
        return self._edge_uri

    @edge_uri.setter
    def edge_uri(self, edge_uri):
        """
        Sets the edge_uri of this DomainLogicalInterface.


        :param edge_uri: The edge_uri of this DomainLogicalInterface.
        :type: str
        """
        self._edge_uri = edge_uri

    @property
    def edge_assigned_id(self):
        """
        Gets the edge_assigned_id of this DomainLogicalInterface.


        :return: The edge_assigned_id of this DomainLogicalInterface.
        :rtype: str
        """
        return self._edge_assigned_id

    @edge_assigned_id.setter
    def edge_assigned_id(self, edge_assigned_id):
        """
        Sets the edge_assigned_id of this DomainLogicalInterface.


        :param edge_assigned_id: The edge_assigned_id of this DomainLogicalInterface.
        :type: str
        """
        self._edge_assigned_id = edge_assigned_id

    @property
    def friendly_name(self):
        """
        Gets the friendly_name of this DomainLogicalInterface.


        :return: The friendly_name of this DomainLogicalInterface.
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """
        Sets the friendly_name of this DomainLogicalInterface.


        :param friendly_name: The friendly_name of this DomainLogicalInterface.
        :type: str
        """
        self._friendly_name = friendly_name

    @property
    def vlan_tag_id(self):
        """
        Gets the vlan_tag_id of this DomainLogicalInterface.


        :return: The vlan_tag_id of this DomainLogicalInterface.
        :rtype: int
        """
        return self._vlan_tag_id

    @vlan_tag_id.setter
    def vlan_tag_id(self, vlan_tag_id):
        """
        Sets the vlan_tag_id of this DomainLogicalInterface.


        :param vlan_tag_id: The vlan_tag_id of this DomainLogicalInterface.
        :type: int
        """
        self._vlan_tag_id = vlan_tag_id

    @property
    def hardware_address(self):
        """
        Gets the hardware_address of this DomainLogicalInterface.


        :return: The hardware_address of this DomainLogicalInterface.
        :rtype: str
        """
        return self._hardware_address

    @hardware_address.setter
    def hardware_address(self, hardware_address):
        """
        Sets the hardware_address of this DomainLogicalInterface.


        :param hardware_address: The hardware_address of this DomainLogicalInterface.
        :type: str
        """
        self._hardware_address = hardware_address

    @property
    def physical_adapter_id(self):
        """
        Gets the physical_adapter_id of this DomainLogicalInterface.


        :return: The physical_adapter_id of this DomainLogicalInterface.
        :rtype: str
        """
        return self._physical_adapter_id

    @physical_adapter_id.setter
    def physical_adapter_id(self, physical_adapter_id):
        """
        Sets the physical_adapter_id of this DomainLogicalInterface.


        :param physical_adapter_id: The physical_adapter_id of this DomainLogicalInterface.
        :type: str
        """
        self._physical_adapter_id = physical_adapter_id

    @property
    def ip_address(self):
        """
        Gets the ip_address of this DomainLogicalInterface.


        :return: The ip_address of this DomainLogicalInterface.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this DomainLogicalInterface.


        :param ip_address: The ip_address of this DomainLogicalInterface.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def gateway(self):
        """
        Gets the gateway of this DomainLogicalInterface.


        :return: The gateway of this DomainLogicalInterface.
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """
        Sets the gateway of this DomainLogicalInterface.


        :param gateway: The gateway of this DomainLogicalInterface.
        :type: str
        """
        self._gateway = gateway

    @property
    def primary_dns(self):
        """
        Gets the primary_dns of this DomainLogicalInterface.


        :return: The primary_dns of this DomainLogicalInterface.
        :rtype: str
        """
        return self._primary_dns

    @primary_dns.setter
    def primary_dns(self, primary_dns):
        """
        Sets the primary_dns of this DomainLogicalInterface.


        :param primary_dns: The primary_dns of this DomainLogicalInterface.
        :type: str
        """
        self._primary_dns = primary_dns

    @property
    def secondary_dns(self):
        """
        Gets the secondary_dns of this DomainLogicalInterface.


        :return: The secondary_dns of this DomainLogicalInterface.
        :rtype: str
        """
        return self._secondary_dns

    @secondary_dns.setter
    def secondary_dns(self, secondary_dns):
        """
        Sets the secondary_dns of this DomainLogicalInterface.


        :param secondary_dns: The secondary_dns of this DomainLogicalInterface.
        :type: str
        """
        self._secondary_dns = secondary_dns

    @property
    def if_status(self):
        """
        Gets the if_status of this DomainLogicalInterface.


        :return: The if_status of this DomainLogicalInterface.
        :rtype: str
        """
        return self._if_status

    @if_status.setter
    def if_status(self, if_status):
        """
        Sets the if_status of this DomainLogicalInterface.


        :param if_status: The if_status of this DomainLogicalInterface.
        :type: str
        """
        self._if_status = if_status

    @property
    def routes(self):
        """
        Gets the routes of this DomainLogicalInterface.


        :return: The routes of this DomainLogicalInterface.
        :rtype: list[DomainNetworkRoute]
        """
        return self._routes

    @routes.setter
    def routes(self, routes):
        """
        Sets the routes of this DomainLogicalInterface.


        :param routes: The routes of this DomainLogicalInterface.
        :type: list[DomainNetworkRoute]
        """
        self._routes = routes

    @property
    def addresses(self):
        """
        Gets the addresses of this DomainLogicalInterface.


        :return: The addresses of this DomainLogicalInterface.
        :rtype: list[DomainNetworkAddress]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this DomainLogicalInterface.


        :param addresses: The addresses of this DomainLogicalInterface.
        :type: list[DomainNetworkAddress]
        """
        self._addresses = addresses

    @property
    def ipv4_capabilities(self):
        """
        Gets the ipv4_capabilities of this DomainLogicalInterface.


        :return: The ipv4_capabilities of this DomainLogicalInterface.
        :rtype: DomainCapabilities
        """
        return self._ipv4_capabilities

    @ipv4_capabilities.setter
    def ipv4_capabilities(self, ipv4_capabilities):
        """
        Sets the ipv4_capabilities of this DomainLogicalInterface.


        :param ipv4_capabilities: The ipv4_capabilities of this DomainLogicalInterface.
        :type: DomainCapabilities
        """
        self._ipv4_capabilities = ipv4_capabilities

    @property
    def ipv6_capabilities(self):
        """
        Gets the ipv6_capabilities of this DomainLogicalInterface.


        :return: The ipv6_capabilities of this DomainLogicalInterface.
        :rtype: DomainCapabilities
        """
        return self._ipv6_capabilities

    @ipv6_capabilities.setter
    def ipv6_capabilities(self, ipv6_capabilities):
        """
        Sets the ipv6_capabilities of this DomainLogicalInterface.


        :param ipv6_capabilities: The ipv6_capabilities of this DomainLogicalInterface.
        :type: DomainCapabilities
        """
        self._ipv6_capabilities = ipv6_capabilities

    @property
    def current_state(self):
        """
        Gets the current_state of this DomainLogicalInterface.


        :return: The current_state of this DomainLogicalInterface.
        :rtype: str
        """
        return self._current_state

    @current_state.setter
    def current_state(self, current_state):
        """
        Sets the current_state of this DomainLogicalInterface.


        :param current_state: The current_state of this DomainLogicalInterface.
        :type: str
        """
        allowed_values = ["INIT", "CREATING", "UPDATING", "OK", "EXCEPTION", "DELETING"]
        if current_state not in allowed_values:
            raise ValueError(
                "Invalid value for `current_state`, must be one of {0}"
                .format(allowed_values)
            )
        self._current_state = current_state

    @property
    def last_modified_user_id(self):
        """
        Gets the last_modified_user_id of this DomainLogicalInterface.


        :return: The last_modified_user_id of this DomainLogicalInterface.
        :rtype: str
        """
        return self._last_modified_user_id

    @last_modified_user_id.setter
    def last_modified_user_id(self, last_modified_user_id):
        """
        Sets the last_modified_user_id of this DomainLogicalInterface.


        :param last_modified_user_id: The last_modified_user_id of this DomainLogicalInterface.
        :type: str
        """
        self._last_modified_user_id = last_modified_user_id

    @property
    def last_modified_correlation_id(self):
        """
        Gets the last_modified_correlation_id of this DomainLogicalInterface.


        :return: The last_modified_correlation_id of this DomainLogicalInterface.
        :rtype: str
        """
        return self._last_modified_correlation_id

    @last_modified_correlation_id.setter
    def last_modified_correlation_id(self, last_modified_correlation_id):
        """
        Sets the last_modified_correlation_id of this DomainLogicalInterface.


        :param last_modified_correlation_id: The last_modified_correlation_id of this DomainLogicalInterface.
        :type: str
        """
        self._last_modified_correlation_id = last_modified_correlation_id

    @property
    def command_responses(self):
        """
        Gets the command_responses of this DomainLogicalInterface.


        :return: The command_responses of this DomainLogicalInterface.
        :rtype: list[DomainNetworkCommandResponse]
        """
        return self._command_responses

    @command_responses.setter
    def command_responses(self, command_responses):
        """
        Sets the command_responses of this DomainLogicalInterface.


        :param command_responses: The command_responses of this DomainLogicalInterface.
        :type: list[DomainNetworkCommandResponse]
        """
        self._command_responses = command_responses

    @property
    def inherit_phone_trunk_bases(self):
        """
        Gets the inherit_phone_trunk_bases of this DomainLogicalInterface.
        Phone trunk base assignment will be inherited from the Edge Group.

        :return: The inherit_phone_trunk_bases of this DomainLogicalInterface.
        :rtype: bool
        """
        return self._inherit_phone_trunk_bases

    @inherit_phone_trunk_bases.setter
    def inherit_phone_trunk_bases(self, inherit_phone_trunk_bases):
        """
        Sets the inherit_phone_trunk_bases of this DomainLogicalInterface.
        Phone trunk base assignment will be inherited from the Edge Group.

        :param inherit_phone_trunk_bases: The inherit_phone_trunk_bases of this DomainLogicalInterface.
        :type: bool
        """
        self._inherit_phone_trunk_bases = inherit_phone_trunk_bases

    @property
    def inherit_phone_trunk_bases_i_pv4(self):
        """
        Gets the inherit_phone_trunk_bases_i_pv4 of this DomainLogicalInterface.
        The IPv4 phone trunk base assignment will be inherited from the Edge Group.

        :return: The inherit_phone_trunk_bases_i_pv4 of this DomainLogicalInterface.
        :rtype: bool
        """
        return self._inherit_phone_trunk_bases_i_pv4

    @inherit_phone_trunk_bases_i_pv4.setter
    def inherit_phone_trunk_bases_i_pv4(self, inherit_phone_trunk_bases_i_pv4):
        """
        Sets the inherit_phone_trunk_bases_i_pv4 of this DomainLogicalInterface.
        The IPv4 phone trunk base assignment will be inherited from the Edge Group.

        :param inherit_phone_trunk_bases_i_pv4: The inherit_phone_trunk_bases_i_pv4 of this DomainLogicalInterface.
        :type: bool
        """
        self._inherit_phone_trunk_bases_i_pv4 = inherit_phone_trunk_bases_i_pv4

    @property
    def inherit_phone_trunk_bases_i_pv6(self):
        """
        Gets the inherit_phone_trunk_bases_i_pv6 of this DomainLogicalInterface.
        The IPv6 phone trunk base assignment will be inherited from the Edge Group.

        :return: The inherit_phone_trunk_bases_i_pv6 of this DomainLogicalInterface.
        :rtype: bool
        """
        return self._inherit_phone_trunk_bases_i_pv6

    @inherit_phone_trunk_bases_i_pv6.setter
    def inherit_phone_trunk_bases_i_pv6(self, inherit_phone_trunk_bases_i_pv6):
        """
        Sets the inherit_phone_trunk_bases_i_pv6 of this DomainLogicalInterface.
        The IPv6 phone trunk base assignment will be inherited from the Edge Group.

        :param inherit_phone_trunk_bases_i_pv6: The inherit_phone_trunk_bases_i_pv6 of this DomainLogicalInterface.
        :type: bool
        """
        self._inherit_phone_trunk_bases_i_pv6 = inherit_phone_trunk_bases_i_pv6

    @property
    def use_for_internal_edge_communication(self):
        """
        Gets the use_for_internal_edge_communication of this DomainLogicalInterface.
        This interface will be used for all internal edge-to-edge communication using settings from the edgeTrunkBaseAssignment on the Edge Group.

        :return: The use_for_internal_edge_communication of this DomainLogicalInterface.
        :rtype: bool
        """
        return self._use_for_internal_edge_communication

    @use_for_internal_edge_communication.setter
    def use_for_internal_edge_communication(self, use_for_internal_edge_communication):
        """
        Sets the use_for_internal_edge_communication of this DomainLogicalInterface.
        This interface will be used for all internal edge-to-edge communication using settings from the edgeTrunkBaseAssignment on the Edge Group.

        :param use_for_internal_edge_communication: The use_for_internal_edge_communication of this DomainLogicalInterface.
        :type: bool
        """
        self._use_for_internal_edge_communication = use_for_internal_edge_communication

    @property
    def external_trunk_base_assignments(self):
        """
        Gets the external_trunk_base_assignments of this DomainLogicalInterface.
        External trunk base settings to use for external communication from this interface.

        :return: The external_trunk_base_assignments of this DomainLogicalInterface.
        :rtype: list[TrunkBaseAssignment]
        """
        return self._external_trunk_base_assignments

    @external_trunk_base_assignments.setter
    def external_trunk_base_assignments(self, external_trunk_base_assignments):
        """
        Sets the external_trunk_base_assignments of this DomainLogicalInterface.
        External trunk base settings to use for external communication from this interface.

        :param external_trunk_base_assignments: The external_trunk_base_assignments of this DomainLogicalInterface.
        :type: list[TrunkBaseAssignment]
        """
        self._external_trunk_base_assignments = external_trunk_base_assignments

    @property
    def phone_trunk_base_assignments(self):
        """
        Gets the phone_trunk_base_assignments of this DomainLogicalInterface.
        Phone trunk base settings to use for phone communication from this interface.  These settings will be ignored when \"inheritPhoneTrunkBases\" is true.

        :return: The phone_trunk_base_assignments of this DomainLogicalInterface.
        :rtype: list[TrunkBaseAssignment]
        """
        return self._phone_trunk_base_assignments

    @phone_trunk_base_assignments.setter
    def phone_trunk_base_assignments(self, phone_trunk_base_assignments):
        """
        Sets the phone_trunk_base_assignments of this DomainLogicalInterface.
        Phone trunk base settings to use for phone communication from this interface.  These settings will be ignored when \"inheritPhoneTrunkBases\" is true.

        :param phone_trunk_base_assignments: The phone_trunk_base_assignments of this DomainLogicalInterface.
        :type: list[TrunkBaseAssignment]
        """
        self._phone_trunk_base_assignments = phone_trunk_base_assignments

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DomainLogicalInterface.
        The URI for this object

        :return: The self_uri of this DomainLogicalInterface.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DomainLogicalInterface.
        The URI for this object

        :param self_uri: The self_uri of this DomainLogicalInterface.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
PresenceApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class PresenceApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_presence_id(self, presence_id, **kwargs):
        """
        Delete an OrganizationPresence
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_presence_id(presence_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str presence_id: Organization Presence ID (required)
        :return: OrganizationPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['presence_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_presence_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'presence_id' is set
        if ('presence_id' not in params) or (params['presence_id'] is None):
            raise ValueError("Missing the required parameter `presence_id` when calling `delete_presence_id`")

        resource_path = '/api/v2/presencedefinitions/{presenceId}'.replace('{format}', 'json')
        path_params = {}
        if 'presence_id' in params:
            path_params['presenceId'] = params['presence_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationPresence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_presence_id(self, presence_id, **kwargs):
        """
        Get an OrganizationPresence
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_presence_id(presence_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str presence_id: Organization Presence ID (required)
        :return: OrganizationPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['presence_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_presence_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'presence_id' is set
        if ('presence_id' not in params) or (params['presence_id'] is None):
            raise ValueError("Missing the required parameter `presence_id` when calling `get_presence_id`")

        resource_path = '/api/v2/presencedefinitions/{presenceId}'.replace('{format}', 'json')
        path_params = {}
        if 'presence_id' in params:
            path_params['presenceId'] = params['presence_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationPresence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_presencedefinitions(self, **kwargs):
        """
        Get an Organization's list of Presences
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_presencedefinitions(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_number: Page number
        :param int page_size: Page size
        :return: OrganizationPresenceEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_number', 'page_size']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_presencedefinitions" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/presencedefinitions'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationPresenceEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_user_id_presences_source_id(self, user_id, source_id, **kwargs):
        """
        Get a user's Presence
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_id_presences_source_id(user_id, source_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: user Id (required)
        :param str source_id: Source (required)
        :return: UserPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'source_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_id_presences_source_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user_id_presences_source_id`")
        # verify the required parameter 'source_id' is set
        if ('source_id' not in params) or (params['source_id'] is None):
            raise ValueError("Missing the required parameter `source_id` when calling `get_user_id_presences_source_id`")

        resource_path = '/api/v2/users/{userId}/presences/{sourceId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'source_id' in params:
            path_params['sourceId'] = params['source_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserPresence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_user_id_presences_source_id(self, user_id, source_id, **kwargs):
        """
        Patch a user's Presence
        The presence object can be patched one of three ways. Option 1: Set the 'primary' property to true. This will set the 'source' defined in the path as the user's primary presence source. Option 2: Provide the presenceDefinition value. Option 3: Provide the message value.  Option 1 can be combined with Option2 and/or Option 3.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_user_id_presences_source_id(user_id, source_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: user Id (required)
        :param str source_id: Source (required)
        :param UserPresence body: 
        :return: UserPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'source_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_user_id_presences_source_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `patch_user_id_presences_source_id`")
        # verify the required parameter 'source_id' is set
        if ('source_id' not in params) or (params['source_id'] is None):
            raise ValueError("Missing the required parameter `source_id` when calling `patch_user_id_presences_source_id`")

        resource_path = '/api/v2/users/{userId}/presences/{sourceId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'source_id' in params:
            path_params['sourceId'] = params['source_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserPresence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_presencedefinitions(self, body, **kwargs):
        """
        Create an OrganizationPresence
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_presencedefinitions(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param OrganizationPresence body: The OrganizationPresence to create (required)
        :return: OrganizationPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_presencedefinitions" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_presencedefinitions`")

        resource_path = '/api/v2/presencedefinitions'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationPresence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_presence_id(self, presence_id, body, **kwargs):
        """
        Update an OrganizationPresence
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_presence_id(presence_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str presence_id: Organization Presence ID (required)
        :param OrganizationPresence body: The OrganizationPresence to update (required)
        :return: OrganizationPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['presence_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_presence_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'presence_id' is set
        if ('presence_id' not in params) or (params['presence_id'] is None):
            raise ValueError("Missing the required parameter `presence_id` when calling `put_presence_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_presence_id`")

        resource_path = '/api/v2/presencedefinitions/{presenceId}'.replace('{format}', 'json')
        path_params = {}
        if 'presence_id' in params:
            path_params['presenceId'] = params['presence_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationPresence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class OAuthClient(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OAuthClient - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'access_token_validity_seconds': 'int',
            'description': 'str',
            'registered_redirect_uri': 'list[str]',
            'secret': 'str',
            'role_ids': 'list[str]',
            'authorized_grant_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'access_token_validity_seconds': 'accessTokenValiditySeconds',
            'description': 'description',
            'registered_redirect_uri': 'registeredRedirectUri',
            'secret': 'secret',
            'role_ids': 'roleIds',
            'authorized_grant_type': 'authorizedGrantType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._access_token_validity_seconds = None
        self._description = None
        self._registered_redirect_uri = None
        self._secret = None
        self._role_ids = None
        self._authorized_grant_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this OAuthClient.
        The globally unique identifier for the object.

        :return: The id of this OAuthClient.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OAuthClient.
        The globally unique identifier for the object.

        :param id: The id of this OAuthClient.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OAuthClient.
        The name of the OAuth client.

        :return: The name of this OAuthClient.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OAuthClient.
        The name of the OAuth client.

        :param name: The name of this OAuthClient.
        :type: str
        """
        self._name = name

    @property
    def access_token_validity_seconds(self):
        """
        Gets the access_token_validity_seconds of this OAuthClient.
        The number of seconds, between 5mins and 48hrs, until tokens created with this client expire. If this field is omitted, a default of 24 hours will be applied.

        :return: The access_token_validity_seconds of this OAuthClient.
        :rtype: int
        """
        return self._access_token_validity_seconds

    @access_token_validity_seconds.setter
    def access_token_validity_seconds(self, access_token_validity_seconds):
        """
        Sets the access_token_validity_seconds of this OAuthClient.
        The number of seconds, between 5mins and 48hrs, until tokens created with this client expire. If this field is omitted, a default of 24 hours will be applied.

        :param access_token_validity_seconds: The access_token_validity_seconds of this OAuthClient.
        :type: int
        """
        self._access_token_validity_seconds = access_token_validity_seconds

    @property
    def description(self):
        """
        Gets the description of this OAuthClient.


        :return: The description of this OAuthClient.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OAuthClient.


        :param description: The description of this OAuthClient.
        :type: str
        """
        self._description = description

    @property
    def registered_redirect_uri(self):
        """
        Gets the registered_redirect_uri of this OAuthClient.
        List of allowed callbacks for this client. For example: https://myap.example.com/auth/callback

        :return: The registered_redirect_uri of this OAuthClient.
        :rtype: list[str]
        """
        return self._registered_redirect_uri

    @registered_redirect_uri.setter
    def registered_redirect_uri(self, registered_redirect_uri):
        """
        Sets the registered_redirect_uri of this OAuthClient.
        List of allowed callbacks for this client. For example: https://myap.example.com/auth/callback

        :param registered_redirect_uri: The registered_redirect_uri of this OAuthClient.
        :type: list[str]
        """
        self._registered_redirect_uri = registered_redirect_uri

    @property
    def secret(self):
        """
        Gets the secret of this OAuthClient.
        System created secret assigned to this client. Secrets are required for code authorization grants.

        :return: The secret of this OAuthClient.
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """
        Sets the secret of this OAuthClient.
        System created secret assigned to this client. Secrets are required for code authorization grants.

        :param secret: The secret of this OAuthClient.
        :type: str
        """
        self._secret = secret

    @property
    def role_ids(self):
        """
        Gets the role_ids of this OAuthClient.
        Roles assigned to this client. Roles only apply to clients using the client_credential grant

        :return: The role_ids of this OAuthClient.
        :rtype: list[str]
        """
        return self._role_ids

    @role_ids.setter
    def role_ids(self, role_ids):
        """
        Sets the role_ids of this OAuthClient.
        Roles assigned to this client. Roles only apply to clients using the client_credential grant

        :param role_ids: The role_ids of this OAuthClient.
        :type: list[str]
        """
        self._role_ids = role_ids

    @property
    def authorized_grant_type(self):
        """
        Gets the authorized_grant_type of this OAuthClient.
        The OAuth Grant/Client type supported by this client.

        :return: The authorized_grant_type of this OAuthClient.
        :rtype: str
        """
        return self._authorized_grant_type

    @authorized_grant_type.setter
    def authorized_grant_type(self, authorized_grant_type):
        """
        Sets the authorized_grant_type of this OAuthClient.
        The OAuth Grant/Client type supported by this client.

        :param authorized_grant_type: The authorized_grant_type of this OAuthClient.
        :type: str
        """
        allowed_values = ["CODE", "TOKEN", "CLIENT-CREDENTIALS"]
        if authorized_grant_type not in allowed_values:
            raise ValueError(
                "Invalid value for `authorized_grant_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._authorized_grant_type = authorized_grant_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this OAuthClient.
        The URI for this object

        :return: The self_uri of this OAuthClient.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this OAuthClient.
        The URI for this object

        :param self_uri: The self_uri of this OAuthClient.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FacetResultItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacetResultItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'count': 'int',
            'document': 'Document',
            'user': 'User',
            'queue': 'Queue',
            'flow_config_id': 'FlowConfigId',
            'workspace': 'Workspace'
        }

        self.attribute_map = {
            'name': 'name',
            'count': 'count',
            'document': 'document',
            'user': 'user',
            'queue': 'queue',
            'flow_config_id': 'flowConfigId',
            'workspace': 'workspace'
        }

        self._name = None
        self._count = None
        self._document = None
        self._user = None
        self._queue = None
        self._flow_config_id = None
        self._workspace = None

    @property
    def name(self):
        """
        Gets the name of this FacetResultItem.
        For TERM facets this will contain the value of the term that was found userid, docid, etc.

        :return: The name of this FacetResultItem.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FacetResultItem.
        For TERM facets this will contain the value of the term that was found userid, docid, etc.

        :param name: The name of this FacetResultItem.
        :type: str
        """
        self._name = name

    @property
    def count(self):
        """
        Gets the count of this FacetResultItem.
        The number of items that matched the facetRequest.

        :return: The count of this FacetResultItem.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this FacetResultItem.
        The number of items that matched the facetRequest.

        :param count: The count of this FacetResultItem.
        :type: int
        """
        self._count = count

    @property
    def document(self):
        """
        Gets the document of this FacetResultItem.


        :return: The document of this FacetResultItem.
        :rtype: Document
        """
        return self._document

    @document.setter
    def document(self, document):
        """
        Sets the document of this FacetResultItem.


        :param document: The document of this FacetResultItem.
        :type: Document
        """
        self._document = document

    @property
    def user(self):
        """
        Gets the user of this FacetResultItem.


        :return: The user of this FacetResultItem.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this FacetResultItem.


        :param user: The user of this FacetResultItem.
        :type: User
        """
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this FacetResultItem.


        :return: The queue of this FacetResultItem.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this FacetResultItem.


        :param queue: The queue of this FacetResultItem.
        :type: Queue
        """
        self._queue = queue

    @property
    def flow_config_id(self):
        """
        Gets the flow_config_id of this FacetResultItem.


        :return: The flow_config_id of this FacetResultItem.
        :rtype: FlowConfigId
        """
        return self._flow_config_id

    @flow_config_id.setter
    def flow_config_id(self, flow_config_id):
        """
        Sets the flow_config_id of this FacetResultItem.


        :param flow_config_id: The flow_config_id of this FacetResultItem.
        :type: FlowConfigId
        """
        self._flow_config_id = flow_config_id

    @property
    def workspace(self):
        """
        Gets the workspace of this FacetResultItem.


        :return: The workspace of this FacetResultItem.
        :rtype: Workspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this FacetResultItem.


        :param workspace: The workspace of this FacetResultItem.
        :type: Workspace
        """
        self._workspace = workspace

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AnalyticsEvaluation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsEvaluation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'evaluation_id': 'str',
            'evaluator_id': 'str',
            'user_id': 'str',
            'event_time': 'str',
            'queue_id': 'str',
            'form_id': 'str',
            'context_id': 'str',
            'form_name': 'str',
            'geto_total_score': 'int',
            'geto_total_critical_score': 'int'
        }

        self.attribute_map = {
            'evaluation_id': 'evaluationId',
            'evaluator_id': 'evaluatorId',
            'user_id': 'userId',
            'event_time': 'eventTime',
            'queue_id': 'queueId',
            'form_id': 'formId',
            'context_id': 'contextId',
            'form_name': 'formName',
            'geto_total_score': 'getoTotalScore',
            'geto_total_critical_score': 'getoTotalCriticalScore'
        }

        self._evaluation_id = None
        self._evaluator_id = None
        self._user_id = None
        self._event_time = None
        self._queue_id = None
        self._form_id = None
        self._context_id = None
        self._form_name = None
        self._geto_total_score = None
        self._geto_total_critical_score = None

    @property
    def evaluation_id(self):
        """
        Gets the evaluation_id of this AnalyticsEvaluation.


        :return: The evaluation_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._evaluation_id

    @evaluation_id.setter
    def evaluation_id(self, evaluation_id):
        """
        Sets the evaluation_id of this AnalyticsEvaluation.


        :param evaluation_id: The evaluation_id of this AnalyticsEvaluation.
        :type: str
        """
        self._evaluation_id = evaluation_id

    @property
    def evaluator_id(self):
        """
        Gets the evaluator_id of this AnalyticsEvaluation.


        :return: The evaluator_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._evaluator_id

    @evaluator_id.setter
    def evaluator_id(self, evaluator_id):
        """
        Sets the evaluator_id of this AnalyticsEvaluation.


        :param evaluator_id: The evaluator_id of this AnalyticsEvaluation.
        :type: str
        """
        self._evaluator_id = evaluator_id

    @property
    def user_id(self):
        """
        Gets the user_id of this AnalyticsEvaluation.


        :return: The user_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this AnalyticsEvaluation.


        :param user_id: The user_id of this AnalyticsEvaluation.
        :type: str
        """
        self._user_id = user_id

    @property
    def event_time(self):
        """
        Gets the event_time of this AnalyticsEvaluation.


        :return: The event_time of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """
        Sets the event_time of this AnalyticsEvaluation.


        :param event_time: The event_time of this AnalyticsEvaluation.
        :type: str
        """
        self._event_time = event_time

    @property
    def queue_id(self):
        """
        Gets the queue_id of this AnalyticsEvaluation.


        :return: The queue_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this AnalyticsEvaluation.


        :param queue_id: The queue_id of this AnalyticsEvaluation.
        :type: str
        """
        self._queue_id = queue_id

    @property
    def form_id(self):
        """
        Gets the form_id of this AnalyticsEvaluation.


        :return: The form_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """
        Sets the form_id of this AnalyticsEvaluation.


        :param form_id: The form_id of this AnalyticsEvaluation.
        :type: str
        """
        self._form_id = form_id

    @property
    def context_id(self):
        """
        Gets the context_id of this AnalyticsEvaluation.


        :return: The context_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """
        Sets the context_id of this AnalyticsEvaluation.


        :param context_id: The context_id of this AnalyticsEvaluation.
        :type: str
        """
        self._context_id = context_id

    @property
    def form_name(self):
        """
        Gets the form_name of this AnalyticsEvaluation.


        :return: The form_name of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._form_name

    @form_name.setter
    def form_name(self, form_name):
        """
        Sets the form_name of this AnalyticsEvaluation.


        :param form_name: The form_name of this AnalyticsEvaluation.
        :type: str
        """
        self._form_name = form_name

    @property
    def geto_total_score(self):
        """
        Gets the geto_total_score of this AnalyticsEvaluation.


        :return: The geto_total_score of this AnalyticsEvaluation.
        :rtype: int
        """
        return self._geto_total_score

    @geto_total_score.setter
    def geto_total_score(self, geto_total_score):
        """
        Sets the geto_total_score of this AnalyticsEvaluation.


        :param geto_total_score: The geto_total_score of this AnalyticsEvaluation.
        :type: int
        """
        self._geto_total_score = geto_total_score

    @property
    def geto_total_critical_score(self):
        """
        Gets the geto_total_critical_score of this AnalyticsEvaluation.


        :return: The geto_total_critical_score of this AnalyticsEvaluation.
        :rtype: int
        """
        return self._geto_total_critical_score

    @geto_total_critical_score.setter
    def geto_total_critical_score(self, geto_total_critical_score):
        """
        Sets the geto_total_critical_score of this AnalyticsEvaluation.


        :param geto_total_critical_score: The geto_total_critical_score of this AnalyticsEvaluation.
        :type: int
        """
        self._geto_total_critical_score = geto_total_critical_score

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FaxDocument(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FaxDocument - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'content_uri': 'str',
            'workspace': 'UriReference',
            'created_by': 'UriReference',
            'content_type': 'str',
            'content_length': 'int',
            'filename': 'str',
            'read': 'bool',
            'page_count': 'int',
            'caller_address': 'str',
            'receiver_address': 'str',
            'thumbnails': 'list[DocumentThumbnail]',
            'sharing_uri': 'str',
            'download_sharing_uri': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'content_uri': 'contentUri',
            'workspace': 'workspace',
            'created_by': 'createdBy',
            'content_type': 'contentType',
            'content_length': 'contentLength',
            'filename': 'filename',
            'read': 'read',
            'page_count': 'pageCount',
            'caller_address': 'callerAddress',
            'receiver_address': 'receiverAddress',
            'thumbnails': 'thumbnails',
            'sharing_uri': 'sharingUri',
            'download_sharing_uri': 'downloadSharingUri',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._content_uri = None
        self._workspace = None
        self._created_by = None
        self._content_type = None
        self._content_length = None
        self._filename = None
        self._read = False
        self._page_count = None
        self._caller_address = None
        self._receiver_address = None
        self._thumbnails = None
        self._sharing_uri = None
        self._download_sharing_uri = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FaxDocument.
        The globally unique identifier for the object.

        :return: The id of this FaxDocument.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FaxDocument.
        The globally unique identifier for the object.

        :param id: The id of this FaxDocument.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FaxDocument.


        :return: The name of this FaxDocument.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FaxDocument.


        :param name: The name of this FaxDocument.
        :type: str
        """
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this FaxDocument.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this FaxDocument.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this FaxDocument.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this FaxDocument.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this FaxDocument.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this FaxDocument.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this FaxDocument.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this FaxDocument.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def content_uri(self):
        """
        Gets the content_uri of this FaxDocument.


        :return: The content_uri of this FaxDocument.
        :rtype: str
        """
        return self._content_uri

    @content_uri.setter
    def content_uri(self, content_uri):
        """
        Sets the content_uri of this FaxDocument.


        :param content_uri: The content_uri of this FaxDocument.
        :type: str
        """
        self._content_uri = content_uri

    @property
    def workspace(self):
        """
        Gets the workspace of this FaxDocument.


        :return: The workspace of this FaxDocument.
        :rtype: UriReference
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this FaxDocument.


        :param workspace: The workspace of this FaxDocument.
        :type: UriReference
        """
        self._workspace = workspace

    @property
    def created_by(self):
        """
        Gets the created_by of this FaxDocument.


        :return: The created_by of this FaxDocument.
        :rtype: UriReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this FaxDocument.


        :param created_by: The created_by of this FaxDocument.
        :type: UriReference
        """
        self._created_by = created_by

    @property
    def content_type(self):
        """
        Gets the content_type of this FaxDocument.


        :return: The content_type of this FaxDocument.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this FaxDocument.


        :param content_type: The content_type of this FaxDocument.
        :type: str
        """
        self._content_type = content_type

    @property
    def content_length(self):
        """
        Gets the content_length of this FaxDocument.


        :return: The content_length of this FaxDocument.
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """
        Sets the content_length of this FaxDocument.


        :param content_length: The content_length of this FaxDocument.
        :type: int
        """
        self._content_length = content_length

    @property
    def filename(self):
        """
        Gets the filename of this FaxDocument.


        :return: The filename of this FaxDocument.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this FaxDocument.


        :param filename: The filename of this FaxDocument.
        :type: str
        """
        self._filename = filename

    @property
    def read(self):
        """
        Gets the read of this FaxDocument.


        :return: The read of this FaxDocument.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this FaxDocument.


        :param read: The read of this FaxDocument.
        :type: bool
        """
        self._read = read

    @property
    def page_count(self):
        """
        Gets the page_count of this FaxDocument.


        :return: The page_count of this FaxDocument.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this FaxDocument.


        :param page_count: The page_count of this FaxDocument.
        :type: int
        """
        self._page_count = page_count

    @property
    def caller_address(self):
        """
        Gets the caller_address of this FaxDocument.


        :return: The caller_address of this FaxDocument.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this FaxDocument.


        :param caller_address: The caller_address of this FaxDocument.
        :type: str
        """
        self._caller_address = caller_address

    @property
    def receiver_address(self):
        """
        Gets the receiver_address of this FaxDocument.


        :return: The receiver_address of this FaxDocument.
        :rtype: str
        """
        return self._receiver_address

    @receiver_address.setter
    def receiver_address(self, receiver_address):
        """
        Sets the receiver_address of this FaxDocument.


        :param receiver_address: The receiver_address of this FaxDocument.
        :type: str
        """
        self._receiver_address = receiver_address

    @property
    def thumbnails(self):
        """
        Gets the thumbnails of this FaxDocument.


        :return: The thumbnails of this FaxDocument.
        :rtype: list[DocumentThumbnail]
        """
        return self._thumbnails

    @thumbnails.setter
    def thumbnails(self, thumbnails):
        """
        Sets the thumbnails of this FaxDocument.


        :param thumbnails: The thumbnails of this FaxDocument.
        :type: list[DocumentThumbnail]
        """
        self._thumbnails = thumbnails

    @property
    def sharing_uri(self):
        """
        Gets the sharing_uri of this FaxDocument.


        :return: The sharing_uri of this FaxDocument.
        :rtype: str
        """
        return self._sharing_uri

    @sharing_uri.setter
    def sharing_uri(self, sharing_uri):
        """
        Sets the sharing_uri of this FaxDocument.


        :param sharing_uri: The sharing_uri of this FaxDocument.
        :type: str
        """
        self._sharing_uri = sharing_uri

    @property
    def download_sharing_uri(self):
        """
        Gets the download_sharing_uri of this FaxDocument.


        :return: The download_sharing_uri of this FaxDocument.
        :rtype: str
        """
        return self._download_sharing_uri

    @download_sharing_uri.setter
    def download_sharing_uri(self, download_sharing_uri):
        """
        Sets the download_sharing_uri of this FaxDocument.


        :param download_sharing_uri: The download_sharing_uri of this FaxDocument.
        :type: str
        """
        self._download_sharing_uri = download_sharing_uri

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FaxDocument.
        The URI for this object

        :return: The self_uri of this FaxDocument.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FaxDocument.
        The URI for this object

        :param self_uri: The self_uri of this FaxDocument.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TrunkBaseAssignment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TrunkBaseAssignment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'family': 'int',
            'trunk_base': 'UriReference'
        }

        self.attribute_map = {
            'family': 'family',
            'trunk_base': 'trunkBase'
        }

        self._family = None
        self._trunk_base = None

    @property
    def family(self):
        """
        Gets the family of this TrunkBaseAssignment.
        The address family to use with the trunk base settings. 2=IPv4, 23=IPv6

        :return: The family of this TrunkBaseAssignment.
        :rtype: int
        """
        return self._family

    @family.setter
    def family(self, family):
        """
        Sets the family of this TrunkBaseAssignment.
        The address family to use with the trunk base settings. 2=IPv4, 23=IPv6

        :param family: The family of this TrunkBaseAssignment.
        :type: int
        """
        self._family = family

    @property
    def trunk_base(self):
        """
        Gets the trunk_base of this TrunkBaseAssignment.
        A trunk base settings reference.

        :return: The trunk_base of this TrunkBaseAssignment.
        :rtype: UriReference
        """
        return self._trunk_base

    @trunk_base.setter
    def trunk_base(self, trunk_base):
        """
        Sets the trunk_base of this TrunkBaseAssignment.
        A trunk base settings reference.

        :param trunk_base: The trunk_base of this TrunkBaseAssignment.
        :type: UriReference
        """
        self._trunk_base = trunk_base

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowHistoryResultItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowHistoryResultItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'flow_instance': 'FlowDetails',
            'available_actions': 'BackendFlowAvailableActions',
            'history_items': 'list[FlowHistoryItem]'
        }

        self.attribute_map = {
            'flow_instance': 'flowInstance',
            'available_actions': 'availableActions',
            'history_items': 'historyItems'
        }

        self._flow_instance = None
        self._available_actions = None
        self._history_items = None

    @property
    def flow_instance(self):
        """
        Gets the flow_instance of this FlowHistoryResultItem.
        The flow instance information that applies to the history events.

        :return: The flow_instance of this FlowHistoryResultItem.
        :rtype: FlowDetails
        """
        return self._flow_instance

    @flow_instance.setter
    def flow_instance(self, flow_instance):
        """
        Sets the flow_instance of this FlowHistoryResultItem.
        The flow instance information that applies to the history events.

        :param flow_instance: The flow_instance of this FlowHistoryResultItem.
        :type: FlowDetails
        """
        self._flow_instance = flow_instance

    @property
    def available_actions(self):
        """
        Gets the available_actions of this FlowHistoryResultItem.
        The actions available for operating in the flow, with respect to your authorization identity.

        :return: The available_actions of this FlowHistoryResultItem.
        :rtype: BackendFlowAvailableActions
        """
        return self._available_actions

    @available_actions.setter
    def available_actions(self, available_actions):
        """
        Sets the available_actions of this FlowHistoryResultItem.
        The actions available for operating in the flow, with respect to your authorization identity.

        :param available_actions: The available_actions of this FlowHistoryResultItem.
        :type: BackendFlowAvailableActions
        """
        self._available_actions = available_actions

    @property
    def history_items(self):
        """
        Gets the history_items of this FlowHistoryResultItem.
        The ordered list of history events for this flow.

        :return: The history_items of this FlowHistoryResultItem.
        :rtype: list[FlowHistoryItem]
        """
        return self._history_items

    @history_items.setter
    def history_items(self, history_items):
        """
        Sets the history_items of this FlowHistoryResultItem.
        The ordered list of history events for this flow.

        :param history_items: The history_items of this FlowHistoryResultItem.
        :type: list[FlowHistoryItem]
        """
        self._history_items = history_items

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Control(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Control - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'label': 'str',
            'options': 'list[ControlOptions]',
            'required': 'bool',
            'read_only': 'bool',
            'variable_binding_id': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'label': 'label',
            'options': 'options',
            'required': 'required',
            'read_only': 'readOnly',
            'variable_binding_id': 'variableBindingId',
            'type': 'type'
        }

        self._id = None
        self._label = None
        self._options = None
        self._required = False
        self._read_only = False
        self._variable_binding_id = None
        self._type = None

    @property
    def id(self):
        """
        Gets the id of this Control.


        :return: The id of this Control.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Control.


        :param id: The id of this Control.
        :type: str
        """
        self._id = id

    @property
    def label(self):
        """
        Gets the label of this Control.


        :return: The label of this Control.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this Control.


        :param label: The label of this Control.
        :type: str
        """
        self._label = label

    @property
    def options(self):
        """
        Gets the options of this Control.


        :return: The options of this Control.
        :rtype: list[ControlOptions]
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this Control.


        :param options: The options of this Control.
        :type: list[ControlOptions]
        """
        self._options = options

    @property
    def required(self):
        """
        Gets the required of this Control.


        :return: The required of this Control.
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """
        Sets the required of this Control.


        :param required: The required of this Control.
        :type: bool
        """
        self._required = required

    @property
    def read_only(self):
        """
        Gets the read_only of this Control.


        :return: The read_only of this Control.
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """
        Sets the read_only of this Control.


        :param read_only: The read_only of this Control.
        :type: bool
        """
        self._read_only = read_only

    @property
    def variable_binding_id(self):
        """
        Gets the variable_binding_id of this Control.


        :return: The variable_binding_id of this Control.
        :rtype: str
        """
        return self._variable_binding_id

    @variable_binding_id.setter
    def variable_binding_id(self, variable_binding_id):
        """
        Sets the variable_binding_id of this Control.


        :param variable_binding_id: The variable_binding_id of this Control.
        :type: str
        """
        self._variable_binding_id = variable_binding_id

    @property
    def type(self):
        """
        Gets the type of this Control.


        :return: The type of this Control.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Control.


        :param type: The type of this Control.
        :type: str
        """
        allowed_values = ["CHECKBOX", "RADIO", "SELECT"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import models into sdk package
from .models.account import Account
from .models.account_manager import AccountManager
from .models.account_overview import AccountOverview
from .models.account_status import AccountStatus
from .models.actions import Actions
from .models.acw_settings import AcwSettings
from .models.address import Address
from .models.address_listing import AddressListing
from .models.agent import Agent
from .models.agent_activity import AgentActivity
from .models.agent_activity_entity_listing import AgentActivityEntityListing
from .models.agent_evaluator_activity import AgentEvaluatorActivity
from .models.aggregate_data_container import AggregateDataContainer
from .models.aggregate_metric_data import AggregateMetricData
from .models.aggregate_query_response import AggregateQueryResponse
from .models.aggregation_query import AggregationQuery
from .models.aggregation_range import AggregationRange
from .models.aggregation_result import AggregationResult
from .models.aggregation_result_entry import AggregationResultEntry
from .models.analytics_conversation import AnalyticsConversation
from .models.analytics_conversation_query_response import AnalyticsConversationQueryResponse
from .models.analytics_conversation_segment import AnalyticsConversationSegment
from .models.analytics_evaluation import AnalyticsEvaluation
from .models.analytics_participant import AnalyticsParticipant
from .models.analytics_property import AnalyticsProperty
from .models.analytics_query_aggregation import AnalyticsQueryAggregation
from .models.analytics_query_clause import AnalyticsQueryClause
from .models.analytics_query_filter import AnalyticsQueryFilter
from .models.analytics_query_predicate import AnalyticsQueryPredicate
from .models.analytics_session import AnalyticsSession
from .models.annotation import Annotation
from .models.app import App
from .models.architect_audit_message import ArchitectAuditMessage
from .models.architect_audit_message_listing import ArchitectAuditMessageListing
from .models.archive_retention import ArchiveRetention
from .models.associated_document import AssociatedDocument
from .models.attachment import Attachment
from .models.attribute import Attribute
from .models.attribute_entity_listing import AttributeEntityListing
from .models.attribute_filter_item import AttributeFilterItem
from .models.attribute_query_request import AttributeQueryRequest
from .models.audit_change import AuditChange
from .models.audit_entity import AuditEntity
from .models.audit_entity_reference import AuditEntityReference
from .models.audit_facet import AuditFacet
from .models.audit_filter import AuditFilter
from .models.audit_message import AuditMessage
from .models.audit_search_result import AuditSearchResult
from .models.audit_user import AuditUser
from .models.available_additional_service import AvailableAdditionalService
from .models.available_additional_service_listing import AvailableAdditionalServiceListing
from .models.available_topic import AvailableTopic
from .models.available_topic_entity_listing import AvailableTopicEntityListing
from .models.backend_flow_available_actions import BackendFlowAvailableActions
from .models.basic_transform import BasicTransform
from .models.batch_command import BatchCommand
from .models.batch_item import BatchItem
from .models.batch_item_body import BatchItemBody
from .models.batch_reply import BatchReply
from .models.batch_reply_item import BatchReplyItem
from .models.billing_address import BillingAddress
from .models.billing_pending_task import BillingPendingTask
from .models.billing_period import BillingPeriod
from .models.billing_task_result import BillingTaskResult
from .models.bullseye import Bullseye
from .models.calibration import Calibration
from .models.calibration_assignment import CalibrationAssignment
from .models.calibration_entity_listing import CalibrationEntityListing
from .models.call import Call
from .models.call_command import CallCommand
from .models.call_conversation import CallConversation
from .models.call_conversation_entity_listing import CallConversationEntityListing
from .models.call_forwarding import CallForwarding
from .models.call_media_participant import CallMediaParticipant
from .models.call_media_policy import CallMediaPolicy
from .models.call_media_policy_conditions import CallMediaPolicyConditions
from .models.call_record import CallRecord
from .models.callable_contacts_diagnostic import CallableContactsDiagnostic
from .models.callable_time import CallableTime
from .models.callable_time_set import CallableTimeSet
from .models.callable_time_set_entity_listing import CallableTimeSetEntityListing
from .models.callback import Callback
from .models.callback_conversation import CallbackConversation
from .models.callback_conversation_entity_listing import CallbackConversationEntityListing
from .models.callback_media_participant import CallbackMediaParticipant
from .models.campaign import Campaign
from .models.campaign_diagnostics import CampaignDiagnostics
from .models.campaign_entity_listing import CampaignEntityListing
from .models.campaign_progress import CampaignProgress
from .models.campaign_schedule import CampaignSchedule
from .models.campaign_schedule_intervals import CampaignScheduleIntervals
from .models.campaign_sequence import CampaignSequence
from .models.campaign_sequence_entity_listing import CampaignSequenceEntityListing
from .models.campaign_stats import CampaignStats
from .models.campaign_time_slot import CampaignTimeSlot
from .models.carrier import Carrier
from .models.carrier_address import CarrierAddress
from .models.carrier_entity_listing import CarrierEntityListing
from .models.certificate import Certificate
from .models.certificate_authority_entity_listing import CertificateAuthorityEntityListing
from .models.certificate_details import CertificateDetails
from .models.change import Change
from .models.channel import Channel
from .models.channel_entity_listing import ChannelEntityListing
from .models.channel_topic import ChannelTopic
from .models.channel_topic_entity_listing import ChannelTopicEntityListing
from .models.charge import Charge
from .models.chat import Chat
from .models.chat_conversation import ChatConversation
from .models.chat_conversation_entity_listing import ChatConversationEntityListing
from .models.chat_media_participant import ChatMediaParticipant
from .models.chat_media_policy import ChatMediaPolicy
from .models.chat_media_policy_conditions import ChatMediaPolicyConditions
from .models.chat_message import ChatMessage
from .models.chat_message_user import ChatMessageUser
from .models.client_spreadsheet_transform import ClientSpreadsheetTransform
from .models.client_text_table_transform import ClientTextTableTransform
from .models.column_collapse import ColumnCollapse
from .models.command_status import CommandStatus
from .models.command_status_entity_listing import CommandStatusEntityListing
from .models.composer_template import ComposerTemplate
from .models.condition import Condition
from .models.connect_rate import ConnectRate
from .models.consult_transfer import ConsultTransfer
from .models.consult_transfer_response import ConsultTransferResponse
from .models.consult_transfer_update import ConsultTransferUpdate
from .models.consumed_resources_entity_listing import ConsumedResourcesEntityListing
from .models.consuming_resources_entity_listing import ConsumingResourcesEntityListing
from .models.contact import Contact
from .models.contact_address import ContactAddress
from .models.contact_callback_request import ContactCallbackRequest
from .models.contact_list import ContactList
from .models.contact_list_entity_listing import ContactListEntityListing
from .models.contact_listing import ContactListing
from .models.contact_phone_number_column import ContactPhoneNumberColumn
from .models.contact_sales import ContactSales
from .models.contact_sales_response import ContactSalesResponse
from .models.contact_sort import ContactSort
from .models.content_attribute_filter_item import ContentAttributeFilterItem
from .models.content_facet_filter_item import ContentFacetFilterItem
from .models.content_filter_item import ContentFilterItem
from .models.content_query_request import ContentQueryRequest
from .models.content_sort_item import ContentSortItem
from .models.contract import Contract
from .models.contract_job import ContractJob
from .models.control import Control
from .models.control_options import ControlOptions
from .models.conversation import Conversation
from .models.conversation_chat import ConversationChat
from .models.conversation_entity_listing import ConversationEntityListing
from .models.conversation_query import ConversationQuery
from .models.cover_sheet import CoverSheet
from .models.create_call_request import CreateCallRequest
from .models.create_call_response import CreateCallResponse
from .models.create_callback_command import CreateCallbackCommand
from .models.create_share_request import CreateShareRequest
from .models.create_share_request_member import CreateShareRequestMember
from .models.create_share_response import CreateShareResponse
from .models.create_template_from_script_request_data import CreateTemplateFromScriptRequestData
from .models.create_user import CreateUser
from .models.csv_schema import CsvSchema
from .models.currency import Currency
from .models.customer_account import CustomerAccount
from .models.did import DID
from .models.did_entity_listing import DIDEntityListing
from .models.did_pool import DIDPool
from .models.did_pool_entity_listing import DIDPoolEntityListing
from .models.data_item import DataItem
from .models.data_value_info import DataValueInfo
from .models.default_greeting_list import DefaultGreetingList
from .models.delete_retention import DeleteRetention
from .models.deleted_resource_consumer_entity_listing import DeletedResourceConsumerEntityListing
from .models.delta_document import DeltaDocument
from .models.delta_request import DeltaRequest
from .models.delta_response import DeltaResponse
from .models.dependency import Dependency
from .models.dependency_object import DependencyObject
from .models.dependency_object_entity_listing import DependencyObjectEntityListing
from .models.dependency_status import DependencyStatus
from .models.dependency_type import DependencyType
from .models.dependency_type_entity_listing import DependencyTypeEntityListing
from .models.destination import Destination
from .models.detail import Detail
from .models.diagnostic_email import DiagnosticEmail
from .models.dialer_action import DialerAction
from .models.dialer_audit_request import DialerAuditRequest
from .models.dialer_contact import DialerContact
from .models.dialer_preview import DialerPreview
from .models.dialer_rule import DialerRule
from .models.digit_length import DigitLength
from .models.disconnect_reason import DisconnectReason
from .models.discount import Discount
from .models.dnc_list import DncList
from .models.dnc_list_entity_listing import DncListEntityListing
from .models.dns import Dns
from .models.document import Document
from .models.document_attribute import DocumentAttribute
from .models.document_audit import DocumentAudit
from .models.document_audit_entity_listing import DocumentAuditEntityListing
from .models.document_entity_listing import DocumentEntityListing
from .models.document_thumbnail import DocumentThumbnail
from .models.document_update import DocumentUpdate
from .models.document_upload import DocumentUpload
from .models.domain_billing_period_entity_listing import DomainBillingPeriodEntityListing
from .models.domain_capabilities import DomainCapabilities
from .models.domain_certificate_authority import DomainCertificateAuthority
from .models.domain_edge_software_update_dto import DomainEdgeSoftwareUpdateDto
from .models.domain_edge_software_version_dto import DomainEdgeSoftwareVersionDto
from .models.domain_entity import DomainEntity
from .models.domain_entity_listing import DomainEntityListing
from .models.domain_entity_listing_evaluation_form import DomainEntityListingEvaluationForm
from .models.domain_entity_listing_query_result import DomainEntityListingQueryResult
from .models.domain_invoice_entity_listing import DomainInvoiceEntityListing
from .models.domain_logical_interface import DomainLogicalInterface
from .models.domain_network_address import DomainNetworkAddress
from .models.domain_network_command_response import DomainNetworkCommandResponse
from .models.domain_network_route import DomainNetworkRoute
from .models.domain_org_role_difference import DomainOrgRoleDifference
from .models.domain_organization_product import DomainOrganizationProduct
from .models.domain_organization_role import DomainOrganizationRole
from .models.domain_permission import DomainPermission
from .models.domain_permission_collection import DomainPermissionCollection
from .models.domain_permission_policy import DomainPermissionPolicy
from .models.domain_physical_capabilities import DomainPhysicalCapabilities
from .models.domain_physical_interface import DomainPhysicalInterface
from .models.domain_resource_condition_node import DomainResourceConditionNode
from .models.domain_resource_condition_value import DomainResourceConditionValue
from .models.domain_role import DomainRole
from .models.domain_schema_reference import DomainSchemaReference
from .models.domain_third_party_account_entity_listing import DomainThirdPartyAccountEntityListing
from .models.domain_third_party_subscription_entity_listing import DomainThirdPartySubscriptionEntityListing
from .models.domain_voice_rate_extended_response_item_entity_listing import DomainVoiceRateExtendedResponseItemEntityListing
from .models.domain_voice_rate_international_response_item_entity_listing import DomainVoiceRateInternationalResponseItemEntityListing
from .models.domain_voice_rate_response_item_entity_listing import DomainVoiceRateResponseItemEntityListing
from .models.download_response import DownloadResponse
from .models.duration_condition import DurationCondition
from .models.edge import Edge
from .models.edge_auto_update_config import EdgeAutoUpdateConfig
from .models.edge_entity_listing import EdgeEntityListing
from .models.edge_group import EdgeGroup
from .models.edge_group_entity_listing import EdgeGroupEntityListing
from .models.edge_interface import EdgeInterface
from .models.edge_line import EdgeLine
from .models.edge_line_entity_listing import EdgeLineEntityListing
from .models.edge_logs_job import EdgeLogsJob
from .models.edge_logs_job_file import EdgeLogsJobFile
from .models.edge_logs_job_request import EdgeLogsJobRequest
from .models.edge_logs_job_response import EdgeLogsJobResponse
from .models.edge_logs_job_upload_request import EdgeLogsJobUploadRequest
from .models.edge_version_information import EdgeVersionInformation
from .models.edge_version_report import EdgeVersionReport
from .models.email import Email
from .models.email_address import EmailAddress
from .models.email_attachment import EmailAttachment
from .models.email_conversation import EmailConversation
from .models.email_conversation_entity_listing import EmailConversationEntityListing
from .models.email_media_participant import EmailMediaParticipant
from .models.email_media_policy import EmailMediaPolicy
from .models.email_media_policy_conditions import EmailMediaPolicyConditions
from .models.email_message import EmailMessage
from .models.email_message_listing import EmailMessageListing
from .models.email_setup import EmailSetup
from .models.embedded_signature_view import EmbeddedSignatureView
from .models.encryption_key import EncryptionKey
from .models.encryption_key_entity_listing import EncryptionKeyEntityListing
from .models.endpoint import Endpoint
from .models.endpoint_entity_listing import EndpointEntityListing
from .models.entity import Entity
from .models.entry import Entry
from .models.error_body import ErrorBody
from .models.error_details import ErrorDetails
from .models.estimated_wait_time_predictions import EstimatedWaitTimePredictions
from .models.evaluation import Evaluation
from .models.evaluation_assignment import EvaluationAssignment
from .models.evaluation_entity_listing import EvaluationEntityListing
from .models.evaluation_form import EvaluationForm
from .models.evaluation_form_and_scoring_set import EvaluationFormAndScoringSet
from .models.evaluation_form_entity_listing import EvaluationFormEntityListing
from .models.evaluation_scoring_set import EvaluationScoringSet
from .models.evaluator_activity import EvaluatorActivity
from .models.evaluator_activity_entity_listing import EvaluatorActivityEntityListing
from .models.expansion_criterium import ExpansionCriterium
from .models.expression_response import ExpressionResponse
from .models.extension import Extension
from .models.extension_entity_listing import ExtensionEntityListing
from .models.extension_pool import ExtensionPool
from .models.extension_pool_entity_listing import ExtensionPoolEntityListing
from .models.external_contact import ExternalContact
from .models.external_organization import ExternalOrganization
from .models.external_organization_listing import ExternalOrganizationListing
from .models.facet_entry import FacetEntry
from .models.facet_info import FacetInfo
from .models.facet_key_attribute import FacetKeyAttribute
from .models.facet_request import FacetRequest
from .models.facet_result import FacetResult
from .models.facet_result_item import FacetResultItem
from .models.facet_statistics import FacetStatistics
from .models.facet_term import FacetTerm
from .models.failed_object import FailedObject
from .models.favorite_template_request_data import FavoriteTemplateRequestData
from .models.fax_document import FaxDocument
from .models.fax_document_entity_listing import FaxDocumentEntityListing
from .models.fax_send_request import FaxSendRequest
from .models.fax_send_response import FaxSendResponse
from .models.fax_summary import FaxSummary
from .models.filter_item import FilterItem
from .models.flow import Flow
from .models.flow_body import FlowBody
from .models.flow_body_format import FlowBodyFormat
from .models.flow_config_id import FlowConfigId
from .models.flow_config_meta_data import FlowConfigMetaData
from .models.flow_config_meta_data_entity_listing import FlowConfigMetaDataEntityListing
from .models.flow_details import FlowDetails
from .models.flow_details_search_result import FlowDetailsSearchResult
from .models.flow_entity_listing import FlowEntityListing
from .models.flow_exec_id import FlowExecId
from .models.flow_history_data_item import FlowHistoryDataItem
from .models.flow_history_item import FlowHistoryItem
from .models.flow_history_result_item import FlowHistoryResultItem
from .models.flow_history_result_item_entity_listing import FlowHistoryResultItemEntityListing
from .models.flow_input_data import FlowInputData
from .models.flow_launch_request import FlowLaunchRequest
from .models.flow_publish import FlowPublish
from .models.flow_report_result_item import FlowReportResultItem
from .models.flow_search_request import FlowSearchRequest
from .models.flow_state import FlowState
from .models.flow_terminate_request import FlowTerminateRequest
from .models.flow_upload_response import FlowUploadResponse
from .models.flow_version import FlowVersion
from .models.flow_version_config_meta_data import FlowVersionConfigMetaData
from .models.flow_version_config_meta_data_entity_listing import FlowVersionConfigMetaDataEntityListing
from .models.flow_version_entity_listing import FlowVersionEntityListing
from .models.form import Form
from .models.gateway import Gateway
from .models.geolocation import Geolocation
from .models.geolocation_settings import GeolocationSettings
from .models.gistener import Gistener
from .models.greeting import Greeting
from .models.greeting_audio_file import GreetingAudioFile
from .models.greeting_media_info import GreetingMediaInfo
from .models.greeting_owner import GreetingOwner
from .models.group import Group
from .models.group_entity_listing import GroupEntityListing
from .models.group_members_update import GroupMembersUpdate
from .models.group_tag import GroupTag
from .models.groups_search_response import GroupsSearchResponse
from .models.hipaa_config import HIPAAConfig
from .models.hardware_rate import HardwareRate
from .models.hardware_rate_listing import HardwareRateListing
from .models.health_check_info import HealthCheckInfo
from .models.ivr import IVR
from .models.ivr_entity_listing import IVREntityListing
from .models.import_status import ImportStatus
from .models.inbound_domain import InboundDomain
from .models.inbound_domain_entity_listing import InboundDomainEntityListing
from .models.inbound_route import InboundRoute
from .models.inbound_route_entity_listing import InboundRouteEntityListing
from .models.indexed_transform import IndexedTransform
from .models.integration_type import IntegrationType
from .models.integration_type_entity_listing import IntegrationTypeEntityListing
from .models.interaction_stats_alert import InteractionStatsAlert
from .models.interaction_stats_alert_container import InteractionStatsAlertContainer
from .models.interaction_stats_rule import InteractionStatsRule
from .models.interaction_stats_rule_container import InteractionStatsRuleContainer
from .models.invoice import Invoice
from .models.json_node import JsonNode
from .models.json_node_search_response import JsonNodeSearchResponse
from .models.key_rotation_schedule import KeyRotationSchedule
from .models.language import Language
from .models.language_entity_listing import LanguageEntityListing
from .models.library import Library
from .models.library_entity_listing import LibraryEntityListing
from .models.license import License
from .models.licenses_by_permission import LicensesByPermission
from .models.line import Line
from .models.line_base import LineBase
from .models.line_base_entity_listing import LineBaseEntityListing
from .models.line_entity_listing import LineEntityListing
from .models.line_status import LineStatus
from .models.linked_entity_listing_flow_details import LinkedEntityListingFlowDetails
from .models.linked_entity_listing_work_item_search_details import LinkedEntityListingWorkItemSearchDetails
from .models.lock_info import LockInfo
from .models.logical_interface_entity_listing import LogicalInterfaceEntityListing
from .models.management_unit import ManagementUnit
from .models.management_unit_timezone import ManagementUnitTimezone
from .models.max_participants import MaxParticipants
from .models.media_participant_request import MediaParticipantRequest
from .models.media_policies import MediaPolicies
from .models.media_result import MediaResult
from .models.media_setting import MediaSetting
from .models.media_summary import MediaSummary
from .models.media_summary_detail import MediaSummaryDetail
from .models.member_entity import MemberEntity
from .models.metabase import Metabase
from .models.metered_evaluation_assignment import MeteredEvaluationAssignment
from .models.noc_support import NocSupport
from .models.note import Note
from .models.note_listing import NoteListing
from .models.number import Number
from .models.number_order_request import NumberOrderRequest
from .models.number_plan import NumberPlan
from .models.numeric_range import NumericRange
from .models.o_auth_client import OAuthClient
from .models.o_auth_client_entity_listing import OAuthClientEntityListing
from .models.o_auth_provider import OAuthProvider
from .models.o_auth_provider_entity_listing import OAuthProviderEntityListing
from .models.observation_data_container import ObservationDataContainer
from .models.observation_query import ObservationQuery
from .models.observation_query_response import ObservationQueryResponse
from .models.okta import Okta
from .models.one_login import OneLogin
from .models.order import Order
from .models.org_license_assignment import OrgLicenseAssignment
from .models.org_media_utilization import OrgMediaUtilization
from .models.organization import Organization
from .models.organization_create import OrganizationCreate
from .models.organization_presence import OrganizationPresence
from .models.organization_presence_entity_listing import OrganizationPresenceEntityListing
from .models.organization_product_entity_listing import OrganizationProductEntityListing
from .models.organization_role_entity_listing import OrganizationRoleEntityListing
from .models.orphan_recording import OrphanRecording
from .models.orphan_recording_listing import OrphanRecordingListing
from .models.out_of_office import OutOfOffice
from .models.outbound_route import OutboundRoute
from .models.outbound_route_entity_listing import OutboundRouteEntityListing
from .models.pin_configuration import PINConfiguration
from .models.page import Page
from .models.paging_spec import PagingSpec
from .models.parameter import Parameter
from .models.parsed_certificate import ParsedCertificate
from .models.participant import Participant
from .models.participant_attributes import ParticipantAttributes
from .models.payment_method import PaymentMethod
from .models.payment_method_listing import PaymentMethodListing
from .models.payment_token_provider import PaymentTokenProvider
from .models.permission_collection_entity_listing import PermissionCollectionEntityListing
from .models.permissions import Permissions
from .models.phone import Phone
from .models.phone_base import PhoneBase
from .models.phone_base_entity_listing import PhoneBaseEntityListing
from .models.phone_capabilities import PhoneCapabilities
from .models.phone_column import PhoneColumn
from .models.phone_entity_listing import PhoneEntityListing
from .models.phone_meta_base_entity_listing import PhoneMetaBaseEntityListing
from .models.phone_number import PhoneNumber
from .models.phone_number_column import PhoneNumberColumn
from .models.phone_number_status import PhoneNumberStatus
from .models.phone_status import PhoneStatus
from .models.phones_reboot import PhonesReboot
from .models.physical_interface_entity_listing import PhysicalInterfaceEntityListing
from .models.policy import Policy
from .models.policy_actions import PolicyActions
from .models.policy_conditions import PolicyConditions
from .models.policy_entity_listing import PolicyEntityListing
from .models.policy_error_message import PolicyErrorMessage
from .models.policy_errors import PolicyErrors
from .models.prediction_results import PredictionResults
from .models.presence_query_response import PresenceQueryResponse
from .models.product import Product
from .models.prompt import Prompt
from .models.prompt_asset import PromptAsset
from .models.prompt_asset_entity_listing import PromptAssetEntityListing
from .models.prompt_entity_listing import PromptEntityListing
from .models.property_index_request import PropertyIndexRequest
from .models.provision_info import ProvisionInfo
from .models.publication import Publication
from .models.publish_script_request_data import PublishScriptRequestData
from .models.published_result import PublishedResult
from .models.pure_cloud import PureCloud
from .models.quality_audit import QualityAudit
from .models.quality_audit_page import QualityAuditPage
from .models.query_facet_info import QueryFacetInfo
from .models.query_request import QueryRequest
from .models.query_result import QueryResult
from .models.query_results import QueryResults
from .models.question_group import QuestionGroup
from .models.question_group_score import QuestionGroupScore
from .models.question_score import QuestionScore
from .models.queue import Queue
from .models.queue_entity_listing import QueueEntityListing
from .models.queue_member import QueueMember
from .models.queue_utilization_diagnostic import QueueUtilizationDiagnostic
from .models.quote import Quote
from .models.quote_charge import QuoteCharge
from .models.quote_listing import QuoteListing
from .models.rate import Rate
from .models.reaction import Reaction
from .models.recording import Recording
from .models.recording_email_message import RecordingEmailMessage
from .models.recording_settings import RecordingSettings
from .models.relationship import Relationship
from .models.relationship_listing import RelationshipListing
from .models.replace_request import ReplaceRequest
from .models.replace_response import ReplaceResponse
from .models.report_meta_data import ReportMetaData
from .models.report_meta_data_entity_listing import ReportMetaDataEntityListing
from .models.report_request import ReportRequest
from .models.report_run_entry import ReportRunEntry
from .models.report_run_entry_entity_domain_listing import ReportRunEntryEntityDomainListing
from .models.report_schedule import ReportSchedule
from .models.report_schedule_entity_listing import ReportScheduleEntityListing
from .models.reservation import Reservation
from .models.resource_condition_node import ResourceConditionNode
from .models.resource_condition_value import ResourceConditionValue
from .models.resource_permission_policy import ResourcePermissionPolicy
from .models.response import Response
from .models.response_entity_list import ResponseEntityList
from .models.response_entity_listing import ResponseEntityListing
from .models.response_filter import ResponseFilter
from .models.response_query_request import ResponseQueryRequest
from .models.response_query_results import ResponseQueryResults
from .models.response_set import ResponseSet
from .models.response_set_entity_listing import ResponseSetEntityListing
from .models.response_text import ResponseText
from .models.rest_error_detail import RestErrorDetail
from .models.retention_duration import RetentionDuration
from .models.ring import Ring
from .models.routing_skill import RoutingSkill
from .models.routing_status import RoutingStatus
from .models.rule_set import RuleSet
from .models.rule_set_entity_listing import RuleSetEntityListing
from .models.run_now_response import RunNowResponse
from .models.salesforce import Salesforce
from .models.schedule import Schedule
from .models.schedule_entity_listing import ScheduleEntityListing
from .models.schedule_group import ScheduleGroup
from .models.schedule_group_entity_listing import ScheduleGroupEntityListing
from .models.schema_category import SchemaCategory
from .models.schema_category_entity_listing import SchemaCategoryEntityListing
from .models.schema_reference_entity_listing import SchemaReferenceEntityListing
from .models.script import Script
from .models.script_entity_listing import ScriptEntityListing
from .models.search_aggregation import SearchAggregation
from .models.search_criteria import SearchCriteria
from .models.search_request import SearchRequest
from .models.security_profile import SecurityProfile
from .models.security_profile_entity_listing import SecurityProfileEntityListing
from .models.segment import Segment
from .models.sequence_schedule import SequenceSchedule
from .models.server_date import ServerDate
from .models.service import Service
from .models.service_context import ServiceContext
from .models.service_entity_listing import ServiceEntityListing
from .models.service_level import ServiceLevel
from .models.service_type import ServiceType
from .models.share import Share
from .models.share_entity_listing import ShareEntityListing
from .models.shared_entity import SharedEntity
from .models.shared_response import SharedResponse
from .models.sheet_schema import SheetSchema
from .models.sheet_transform import SheetTransform
from .models.signature_document_info import SignatureDocumentInfo
from .models.site import Site
from .models.site_entity_listing import SiteEntityListing
from .models.skill_entity_listing import SkillEntityListing
from .models.skills_to_remove import SkillsToRemove
from .models.snapshot import Snapshot
from .models.social_account import SocialAccount
from .models.social_conversation import SocialConversation
from .models.social_conversation_entity_listing import SocialConversationEntityListing
from .models.social_expression import SocialExpression
from .models.social_media_participant import SocialMediaParticipant
from .models.socialize_entity_filter import SocializeEntityFilter
from .models.socialize_filter_request import SocializeFilterRequest
from .models.sort_field import SortField
from .models.sort_item import SortItem
from .models.spreadsheet_transform import SpreadsheetTransform
from .models.spreadsheet_transform_entity_listing import SpreadsheetTransformEntityListing
from .models.station import Station
from .models.station_entity_listing import StationEntityListing
from .models.statistical_response import StatisticalResponse
from .models.statistical_summary import StatisticalSummary
from .models.sub_data_item import SubDataItem
from .models.subscriber_response import SubscriberResponse
from .models.support import Support
from .models.system_prompt import SystemPrompt
from .models.system_prompt_asset import SystemPromptAsset
from .models.system_prompt_asset_entity_listing import SystemPromptAssetEntityListing
from .models.system_prompt_entity_listing import SystemPromptEntityListing
from .models.table_transform import TableTransform
from .models.tag_model import TagModel
from .models.tag_query_request import TagQueryRequest
from .models.tag_value import TagValue
from .models.tag_value_entity_listing import TagValueEntityListing
from .models.template_entity_listing import TemplateEntityListing
from .models.term_attribute import TermAttribute
from .models.text_table_transform import TextTableTransform
from .models.text_table_transform_entity_listing import TextTableTransformEntityListing
from .models.third_party_account import ThirdPartyAccount
from .models.third_party_subscription import ThirdPartySubscription
from .models.ticker import Ticker
from .models.tier import Tier
from .models.time_allowed import TimeAllowed
from .models.time_interval import TimeInterval
from .models.time_slot import TimeSlot
from .models.time_zone import TimeZone
from .models.time_zone_entity_listing import TimeZoneEntityListing
from .models.trace import Trace
from .models.trace_list import TraceList
from .models.transfer_request import TransferRequest
from .models.transform_endpoint import TransformEndpoint
from .models.transform_lens import TransformLens
from .models.trunk import Trunk
from .models.trunk_base import TrunkBase
from .models.trunk_base_assignment import TrunkBaseAssignment
from .models.trunk_entity_listing import TrunkEntityListing
from .models.trunk_metabase_entity_listing import TrunkMetabaseEntityListing
from .models.twitter_expression import TwitterExpression
from .models.twitter_expression_buffer import TwitterExpressionBuffer
from .models.unpivot_columns import UnpivotColumns
from .models.unread_metric import UnreadMetric
from .models.unread_status import UnreadStatus
from .models.upload_progress import UploadProgress
from .models.uri_reference import UriReference
from .models.url_response import UrlResponse
from .models.user import User
from .models.user_action_category import UserActionCategory
from .models.user_action_category_entity_listing import UserActionCategoryEntityListing
from .models.user_action_metadata import UserActionMetadata
from .models.user_action_metadata_entity_listing import UserActionMetadataEntityListing
from .models.user_action_metadata_request import UserActionMetadataRequest
from .models.user_authorization import UserAuthorization
from .models.user_conversation_summary import UserConversationSummary
from .models.user_entity_listing import UserEntityListing
from .models.user_image import UserImage
from .models.user_license_assignment import UserLicenseAssignment
from .models.user_me import UserMe
from .models.user_param import UserParam
from .models.user_presence import UserPresence
from .models.user_queue import UserQueue
from .models.user_queue_entity_listing import UserQueueEntityListing
from .models.user_recording import UserRecording
from .models.user_recording_entity_listing import UserRecordingEntityListing
from .models.user_routing_skill import UserRoutingSkill
from .models.user_skill_entity_listing import UserSkillEntityListing
from .models.user_station import UserStation
from .models.user_stations import UserStations
from .models.users_entity_listing import UsersEntityListing
from .models.users_search_response import UsersSearchResponse
from .models.utilization import Utilization
from .models.validate_address_request import ValidateAddressRequest
from .models.validate_address_response import ValidateAddressResponse
from .models.value import Value
from .models.vendor_connection_request import VendorConnectionRequest
from .models.video import Video
from .models.video_conversation import VideoConversation
from .models.video_conversation_entity_listing import VideoConversationEntityListing
from .models.video_media_participant import VideoMediaParticipant
from .models.view import View
from .models.voice_rate import VoiceRate
from .models.voice_rate_extended import VoiceRateExtended
from .models.voice_rate_international import VoiceRateInternational
from .models.voice_rate_international_entity_listing import VoiceRateInternationalEntityListing
from .models.voice_rate_update import VoiceRateUpdate
from .models.voice_rates_csv import VoiceRatesCsv
from .models.voice_xml_operation import VoiceXmlOperation
from .models.voice_xml_operation_entity_listing import VoiceXmlOperationEntityListing
from .models.voicemail_mailbox_info import VoicemailMailboxInfo
from .models.voicemail_media_info import VoicemailMediaInfo
from .models.voicemail_message import VoicemailMessage
from .models.voicemail_message_entity_listing import VoicemailMessageEntityListing
from .models.voicemail_organization_policy import VoicemailOrganizationPolicy
from .models.voicemail_user_policy import VoicemailUserPolicy
from .models.vpn import Vpn
from .models.work_item import WorkItem
from .models.work_item_actions import WorkItemActions
from .models.work_item_cache import WorkItemCache
from .models.work_item_command import WorkItemCommand
from .models.work_item_command_group import WorkItemCommandGroup
from .models.work_item_definition import WorkItemDefinition
from .models.work_item_details import WorkItemDetails
from .models.work_item_search_details import WorkItemSearchDetails
from .models.work_item_search_details_search_result import WorkItemSearchDetailsSearchResult
from .models.work_item_submit_request import WorkItemSubmitRequest
from .models.work_item_transfer_request import WorkItemTransferRequest
from .models.workspace import Workspace
from .models.workspace_create import WorkspaceCreate
from .models.workspace_entity_listing import WorkspaceEntityListing
from .models.workspace_member import WorkspaceMember
from .models.workspace_member_entity_listing import WorkspaceMemberEntityListing
from .models.workspace_summary import WorkspaceSummary
from .models.wrap_up_code_mapping import WrapUpCodeMapping
from .models.wrapup import Wrapup
from .models.wrapup_code import WrapupCode
from .models.wrapup_code_entity_listing import WrapupCodeEntityListing
from .models.xlsx_schema import XlsxSchema

# import apis into sdk package
from .apis.alerting_api import AlertingApi
from .apis.analytics_api import AnalyticsApi
from .apis.attributes_api import AttributesApi
from .apis.authorization_api import AuthorizationApi
from .apis.configuration_api import ConfigurationApi
from .apis.content_management_api import ContentManagementApi
from .apis.conversations_api import ConversationsApi
from .apis.external_contacts_api import ExternalContactsApi
from .apis.fax_api import FaxApi
from .apis.geolocation_api import GeolocationApi
from .apis.greetings_api import GreetingsApi
from .apis.groups_api import GroupsApi
from .apis.languages_api import LanguagesApi
from .apis.notifications_api import NotificationsApi
from .apis.o_auth_api import OAuthApi
from .apis.organization_api import OrganizationApi
from .apis.outbound_api import OutboundApi
from .apis.presence_api import PresenceApi
from .apis.quality_api import QualityApi
from .apis.recording_api import RecordingApi
from .apis.response_management_api import ResponseManagementApi
from .apis.routing_api import RoutingApi
from .apis.search_api import SearchApi
from .apis.stations_api import StationsApi
from .apis.telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .apis.tokens_api import TokensApi
from .apis.user_recordings_api import UserRecordingsApi
from .apis.users_api import UsersApi
from .apis.utilities_api import UtilitiesApi
from .apis.voicemail_api import VoicemailApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
